@@ -32,7 +32,7 @@ var searchData=
   ['libevdev_5fget_5fid_5fproduct',['libevdev_get_id_product',['../group__bits.html#ga1dc66cfef646878d58be72f8902a6bac',1,'libevdev.h']]],
   ['libevdev_5fget_5fid_5fvendor',['libevdev_get_id_vendor',['../group__bits.html#ga08891c3285da5b8d26769c9a34f063f3',1,'libevdev.h']]],
   ['libevdev_5fget_5fid_5fversion',['libevdev_get_id_version',['../group__bits.html#ga75a07d0c96dfe09d2194c104c429d0ae',1,'libevdev.h']]],
-  ['libevdev_5fget_5flog_5fpriority',['libevdev_get_log_priority',['../group__init.html#ga1da07493a798595cf85c127490b98ee8',1,'libevdev.h']]],
+  ['libevdev_5fget_5flog_5fpriority',['libevdev_get_log_priority',['../group__logging.html#ga1da07493a798595cf85c127490b98ee8',1,'libevdev.h']]],
   ['libevdev_5fget_5fname',['libevdev_get_name',['../group__bits.html#gaed0328c67b7a78422636d9fe09a73f12',1,'libevdev.h']]],
   ['libevdev_5fget_5fnum_5fslots',['libevdev_get_num_slots',['../group__mt.html#gaf272526f0a59d2f61ef7389046cd4088',1,'libevdev.h']]],
   ['libevdev_5fget_5fphys',['libevdev_get_phys',['../group__bits.html#ga5df483b0b24d7b96ea1181808fab851d',1,'libevdev.h']]],
@@ -50,6 +50,8 @@ var searchData=
   ['libevdev_5fnew',['libevdev_new',['../group__init.html#ga332c8ee260b4ef864345abe5d04e820c',1,'libevdev.h']]],
   ['libevdev_5fnew_5ffrom_5ffd',['libevdev_new_from_fd',['../group__init.html#ga89bb5bce1c23e293293484b05b12aaf4',1,'libevdev.h']]],
   ['libevdev_5fnext_5fevent',['libevdev_next_event',['../group__events.html#gabb96c864e836c0b98788f4ab771c3a76',1,'libevdev.h']]],
+  ['libevdev_5fproperty_5ffrom_5fname',['libevdev_property_from_name',['../group__misc.html#ga6f4418c98aa475a2fc34d58a197f7edd',1,'libevdev.h']]],
+  ['libevdev_5fproperty_5ffrom_5fname_5fn',['libevdev_property_from_name_n',['../group__misc.html#gaaa0bc4c7d0d2aedc84c7dcffee9ce29b',1,'libevdev.h']]],
   ['libevdev_5fproperty_5fget_5fname',['libevdev_property_get_name',['../group__misc.html#gacc12bdb7b912070ac9c375428f2c9892',1,'libevdev.h']]],
   ['libevdev_5fset_5fabs_5fflat',['libevdev_set_abs_flat',['../group__kernel.html#gad9b091c31c1df99ecc681358aab4a039',1,'libevdev.h']]],
   ['libevdev_5fset_5fabs_5ffuzz',['libevdev_set_abs_fuzz',['../group__kernel.html#ga9f4f81faf4a1702c9076cc839b5746ab',1,'libevdev.h']]],
@@ -58,14 +60,15 @@ var searchData=
   ['libevdev_5fset_5fabs_5fminimum',['libevdev_set_abs_minimum',['../group__kernel.html#ga32507e7798fd7cd863cc730f0d84aac9',1,'libevdev.h']]],
   ['libevdev_5fset_5fabs_5fresolution',['libevdev_set_abs_resolution',['../group__kernel.html#ga71da3214377e99a98c125fbce67d4059',1,'libevdev.h']]],
   ['libevdev_5fset_5fclock_5fid',['libevdev_set_clock_id',['../group__kernel.html#ga2925b6fbf8c7991ff2164424b840b82d',1,'libevdev.h']]],
+  ['libevdev_5fset_5fdevice_5flog_5ffunction',['libevdev_set_device_log_function',['../group__logging.html#ga2830ff0aa391d8d1111682d3e762091b',1,'libevdev.h']]],
   ['libevdev_5fset_5fevent_5fvalue',['libevdev_set_event_value',['../group__kernel.html#ga79e82ee2a95cb08adb4172aabe0c7184',1,'libevdev.h']]],
   ['libevdev_5fset_5ffd',['libevdev_set_fd',['../group__init.html#ga6658ac490d68c307ff8b8d1536c12b44',1,'libevdev.h']]],
   ['libevdev_5fset_5fid_5fbustype',['libevdev_set_id_bustype',['../group__kernel.html#gaf99139c728ba1bd4b37ede612780b6b0',1,'libevdev.h']]],
   ['libevdev_5fset_5fid_5fproduct',['libevdev_set_id_product',['../group__kernel.html#ga62fbdaac056ab5c3db154a9eeaf33799',1,'libevdev.h']]],
   ['libevdev_5fset_5fid_5fvendor',['libevdev_set_id_vendor',['../group__kernel.html#ga8ce28051ebbb73de1d04d782f4d0d6fe',1,'libevdev.h']]],
   ['libevdev_5fset_5fid_5fversion',['libevdev_set_id_version',['../group__kernel.html#gaee1d2db88b191ec21d5bf22dd4fe3055',1,'libevdev.h']]],
-  ['libevdev_5fset_5flog_5ffunction',['libevdev_set_log_function',['../group__init.html#gaa60be86b83b3a6c82d8e536ba89ff955',1,'libevdev.h']]],
-  ['libevdev_5fset_5flog_5fpriority',['libevdev_set_log_priority',['../group__init.html#gaf6b6842a9ed98b61d0abb421e853fd89',1,'libevdev.h']]],
+  ['libevdev_5fset_5flog_5ffunction',['libevdev_set_log_function',['../group__logging.html#gaa60be86b83b3a6c82d8e536ba89ff955',1,'libevdev.h']]],
+  ['libevdev_5fset_5flog_5fpriority',['libevdev_set_log_priority',['../group__logging.html#gaf6b6842a9ed98b61d0abb421e853fd89',1,'libevdev.h']]],
   ['libevdev_5fset_5fname',['libevdev_set_name',['../group__kernel.html#gae5dcdb7678cdc9be4ab1989725b4ed32',1,'libevdev.h']]],
   ['libevdev_5fset_5fphys',['libevdev_set_phys',['../group__kernel.html#gacd57c8d6ace8e0b1417809a9c1c67af3',1,'libevdev.h']]],
   ['libevdev_5fset_5fslot_5fvalue',['libevdev_set_slot_value',['../group__kernel.html#ga0c61f4919b03b0850529a50c37a20333',1,'libevdev.h']]],
