@@ -70,7 +70,7 @@ init_event_queue(struct libevdev *dev)
 	/* count the number of axes, keys, etc. to get a better idea at how
 	   many events per EV_SYN we could possibly get. That's the max we
 	   may get during SYN_DROPPED too. Use double that, just so we have
-	   room for events while syncing an event.
+	   room for events while syncing a device.
 	 */
 	for (type = EV_KEY; type < EV_MAX; type++) {
 		int max = libevdev_event_type_get_max(type);
@@ -84,7 +84,7 @@ init_event_queue(struct libevdev *dev)
 	if (nslots > 1) {
 		int num_mt_axes = 0;
 
-		for (code = ABS_MT_SLOT; code < ABS_MAX; code++) {
+		for (code = ABS_MT_SLOT; code <= ABS_MAX; code++) {
 			if (libevdev_has_event_code(dev, EV_ABS, code))
 				num_mt_axes++;
 		}
@@ -160,7 +160,6 @@ _libevdev_log_msg(const struct libevdev *dev,
 	else if (unlikely(log_data.device_handler))
 		abort(); /* Seppuku, see above */
 
-
 	va_start(args, format);
 	if (dev && dev->log.device_handler)
 		dev->log.device_handler(dev, priority, dev->log.userdata, file, line, func, format, args);
@@ -682,7 +681,6 @@ sync_mt_state(struct libevdev *dev, int create_events)
 				set_bit(slot_update, AXISBIT(slot, ABS_MT_SLOT));
 			}
 
-
 		}
 	}
 
@@ -991,6 +989,10 @@ libevdev_next_event(struct libevdev *dev, unsigned int flags, struct input_event
 {
 	int rc = LIBEVDEV_READ_STATUS_SUCCESS;
 	enum event_filter_status filter_status;
+	const unsigned int valid_flags = LIBEVDEV_READ_FLAG_NORMAL |
+					 LIBEVDEV_READ_FLAG_SYNC |
+					 LIBEVDEV_READ_FLAG_FORCE_SYNC |
+					 LIBEVDEV_READ_FLAG_BLOCKING;
 
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
@@ -998,7 +1000,7 @@ libevdev_next_event(struct libevdev *dev, unsigned int flags, struct input_event
 	} else if (dev->fd < 0)
 		return -EBADF;
 
-	if (!(flags & (LIBEVDEV_READ_FLAG_NORMAL|LIBEVDEV_READ_FLAG_SYNC|LIBEVDEV_READ_FLAG_FORCE_SYNC))) {
+	if ((flags & valid_flags) == 0) {
 		log_bug(dev, "invalid flags %#x.\n", flags);
 		return -EINVAL;
 	}
@@ -1050,7 +1052,6 @@ libevdev_next_event(struct libevdev *dev, unsigned int flags, struct input_event
 			goto out;
 		}
 
-
 		if (queue_shift(dev, ev) != 0)
 			return -EAGAIN;
 
@@ -1136,7 +1137,6 @@ STRING_SETTER(name)
 STRING_SETTER(phys)
 STRING_SETTER(uniq)
 
-
 #define PRODUCT_GETTER(name) \
 LIBEVDEV_EXPORT int libevdev_get_id_##name(const struct libevdev *dev) \
 { \
