@@ -51,8 +51,10 @@ static int
 usage(void) {
 	printf("Usage: %s /dev/input/event0\n", program_invocation_short_name);
 	printf("\n");
-	printf("This tool reads relative events from the kernel and calculates\n "
-	       "the distance covered and frequency of the incoming events.\n");
+	printf("This tool reads relative events from the kernel and calculates\n"
+	       "the distance covered and maximum frequency of the incoming events.\n"
+	       "Some mouse devices provide dynamic frequencies, it is\n"
+	       "recommended to measure multiple times to obtain the highest value.\n");
 	return 1;
 }
 
@@ -181,6 +183,9 @@ print_summary(struct measurements *m)
 		printf("%8dmm	%8.2fin	%8ddpi\n",
 		       (int)(inch * 25.4), inch, res);
 	}
+	printf("If your resolution is not in the list, calculate it with:\n"
+	       "\tresolution=%d/inches, or\n"
+	       "\tresolution=%d/(mm * 25.4)\n", m->distance, m->distance);
 }
 
 static inline const char*
@@ -207,7 +212,7 @@ main (int argc, char **argv) {
 	int fd;
 	const char *path;
 	struct libevdev *dev;
-	struct measurements measurements = {0};
+	struct measurements measurements = {0, 0, 0};
 
 	if (argc < 2)
 		return usage();
@@ -236,7 +241,7 @@ main (int argc, char **argv) {
 	libevdev_grab(dev, LIBEVDEV_UNGRAB);
 
 	printf("Mouse %s on %s\n", libevdev_get_name(dev), path);
-	printf("Move the device along the x-axis.\n");
+	printf("Move the device 250mm/10in or more along the x-axis.\n");
 	printf("Pause 3 seconds before movement to reset, Ctrl+C to exit.\n");
 	setbuf(stdout, NULL);
 
